@@ -1,13 +1,13 @@
 from ..utils import status
 from ..utils.exceptions import HttpError
-from ..utils.throttle import BaseThrottle
+from ..utils.throttle import NullThrottle, AbstractThrottle
 
 
 class ThrottleMeta(type):
-    def __new__(mcs, name, bases, params):
 
+    def __new__(mcs, name, bases, params):
         cls = super(ThrottleMeta, mcs).__new__(mcs, name, bases, params)
-        assert issubclass(cls.throttle, BaseThrottle), "'throttle' must be subclass of BaseThrottle"
+        assert issubclass(cls.throttle, AbstractThrottle), "'throttle' must be subclass of AbstractThrottle"
         return cls
 
 
@@ -15,10 +15,10 @@ class ThrottleMixin(object):
 
     __metaclass__ = ThrottleMeta
 
-    throttle = BaseThrottle
+    throttle = NullThrottle
 
     def throttle_check(self):
         throttle = self.throttle()
-        wait = throttle.should_be_throttled(self.identifier)
+        wait = throttle.should_be_throttled(self)
         if wait:
             raise HttpError("Throttled, wait %d seconds." % wait, status=status.HTTP_503_SERVICE_UNAVAILABLE)
